@@ -21,7 +21,7 @@
 .onLoad <- function(libname, pkgname) {
 	conf = Sys.getenv("SDMX_CONF")
 	if (is.null(conf) || conf=="") {
-		conf =file.path(find.package("RJSDMX"), "inst", "configuration.properties")
+		conf =file.path(find.package("RJSDMX"), "configuration.properties")
 		Sys.setenv(SDMX_CONF=conf)
 	}
 	#packageStartupMessage(paste('Connector configuration:', conf))
